"use strict";
/*
 * Copyright (c) 2008-2021, Hazelcast, Inc. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.SqlFetchCodec = void 0;
/* eslint-disable max-len */
const BitsUtil_1 = require("../util/BitsUtil");
const FixSizedTypesCodec_1 = require("./builtin/FixSizedTypesCodec");
const ClientMessage_1 = require("../protocol/ClientMessage");
const SqlQueryIdCodec_1 = require("./custom/SqlQueryIdCodec");
const SqlPageCodec_1 = require("./builtin/SqlPageCodec");
const CodecUtil_1 = require("./builtin/CodecUtil");
const SqlErrorCodec_1 = require("./custom/SqlErrorCodec");
// hex: 0x210500
const REQUEST_MESSAGE_TYPE = 2163968;
// hex: 0x210501
// RESPONSE_MESSAGE_TYPE = 2163969
const REQUEST_CURSOR_BUFFER_SIZE_OFFSET = ClientMessage_1.PARTITION_ID_OFFSET + BitsUtil_1.BitsUtil.INT_SIZE_IN_BYTES;
const REQUEST_INITIAL_FRAME_SIZE = REQUEST_CURSOR_BUFFER_SIZE_OFFSET + BitsUtil_1.BitsUtil.INT_SIZE_IN_BYTES;
/** @internal */
class SqlFetchCodec {
    static encodeRequest(queryId, cursorBufferSize) {
        const clientMessage = ClientMessage_1.ClientMessage.createForEncode();
        clientMessage.setRetryable(false);
        const initialFrame = ClientMessage_1.Frame.createInitialFrame(REQUEST_INITIAL_FRAME_SIZE);
        FixSizedTypesCodec_1.FixSizedTypesCodec.encodeInt(initialFrame.content, REQUEST_CURSOR_BUFFER_SIZE_OFFSET, cursorBufferSize);
        clientMessage.addFrame(initialFrame);
        clientMessage.setMessageType(REQUEST_MESSAGE_TYPE);
        clientMessage.setPartitionId(-1);
        SqlQueryIdCodec_1.SqlQueryIdCodec.encode(clientMessage, queryId);
        return clientMessage;
    }
    static decodeResponse(clientMessage) {
        // empty initial frame
        clientMessage.nextFrame();
        const response = {};
        response.rowPage = CodecUtil_1.CodecUtil.decodeNullable(clientMessage, SqlPageCodec_1.SqlPageCodec.decode);
        response.error = CodecUtil_1.CodecUtil.decodeNullable(clientMessage, SqlErrorCodec_1.SqlErrorCodec.decode);
        return response;
    }
}
exports.SqlFetchCodec = SqlFetchCodec;
//# sourceMappingURL=SqlFetchCodec.js.map